==> magg-0.3.2-py3-none-any.whl: magg/mbro/test/test_basic_functionality.py <==
"""Basic MBRO functionality tests using pytest."""

import pytest
import asyncio
import subprocess
import time
import signal
from pathlib import Path


class TestMBROBasic:
    """Test basic MBRO functionality."""

    @pytest.fixture
    def magg_server_port(self):
        """Port for test MAGG server."""
        return 8081

    @pytest.fixture(scope="function")
    async def magg_server(self, magg_server_port):
        """Start a MAGG HTTP server for testing."""
        # Start MAGG HTTP server in background
        process = subprocess.Popen(
            ["uv", "run", "magg", "--http", "--port", str(magg_server_port)],
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
            preexec_fn=None if sys.platform == "win32" else lambda: None
        )

        # Wait for server to start
        await asyncio.sleep(3)

        yield process

        # Cleanup
        process.terminate()
        try:
            process.wait(timeout=5)
        except subprocess.TimeoutExpired:
            process.kill()

    @pytest.mark.skip(reason="Integration test requires complex async server setup")
    @pytest.mark.asyncio
    async def test_mbro_connection(self, magg_server, magg_server_port):
        """Test that mbro can connect to MAGG server."""
        # Test mbro connection
        mbro_process = subprocess.Popen(
            ["uv", "run", "python", "-m", "mbro.cli", f"http://localhost:{magg_server_port}", "list"],
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
            text=True
        )

        stdout, stderr = mbro_process.communicate(timeout=10)

        # Should connect successfully
        assert mbro_process.returncode == 0, f"mbro failed: {stderr}"
        assert "tools" in stdout.lower() or "available" in stdout.lower()

    @pytest.mark.skip(reason="Integration test requires complex async server setup")
    @pytest.mark.asyncio
    async def test_mbro_tool_listing(self, magg_server, magg_server_port):
        """Test that mbro can list tools from MAGG."""
        # Test tool listing
        mbro_process = subprocess.Popen(
            ["uv", "run", "python", "-m", "mbro.cli", f"http://localhost:{magg_server_port}", "list"],
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
            text=True
        )

        stdout, stderr = mbro_process.communicate(timeout=10)

        assert mbro_process.returncode == 0
        # Should see MAGG's own tools at minimum
        assert "magg" in stdout.lower()


@pytest.mark.integration
class TestMBROIntegration:
    """Integration tests for MBRO with MAGG."""

    @pytest.mark.asyncio
    async def test_mbro_search_functionality(self):
        """Test mbro search functionality."""
        # This would test the search capabilities
        # Implementation depends on MAGG search being available
        pass

    @pytest.mark.asyncio
    async def test_mbro_tool_execution(self):
        """Test executing tools through mbro."""
        # This would test actual tool execution
        # Implementation depends on having test tools available
        pass

==> magg-0.5.1.52-py3-none-any.whl: magg/mbro/test/test_basic_functionality.py <==
"""Basic MBRO functionality tests using pytest."""

import pytest
import asyncio
import subprocess
import time
import signal
from pathlib import Path


class TestMBROBasic:
    """Test basic MBRO functionality."""

    @pytest.fixture
    def magg_server_port(self):
        """Port for test Magg server."""
        return 8081

    @pytest.fixture(scope="function")
    async def magg_server(self, magg_server_port):
        """Start a Magg HTTP server for testing."""
        # Start Magg HTTP server in background
        process = subprocess.Popen(
            ["uv", "run", "magg", "--http", "--port", str(magg_server_port)],
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
            preexec_fn=None if sys.platform == "win32" else lambda: None
        )

        # Wait for server to start
        await asyncio.sleep(3)

        yield process

        # Cleanup
        process.terminate()
        try:
            process.wait(timeout=5)
        except subprocess.TimeoutExpired:
            process.kill()

    @pytest.mark.skip(reason="Integration test requires complex async server setup")
    @pytest.mark.asyncio
    async def test_mbro_connection(self, magg_server, magg_server_port):
        """Test that mbro can connect to Magg server."""
        # Test mbro connection
        mbro_process = subprocess.Popen(
            ["uv", "run", "python", "-m", "mbro.cli", f"http://localhost:{magg_server_port}", "list"],
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
            text=True
        )

        stdout, stderr = mbro_process.communicate(timeout=10)

        # Should connect successfully
        assert mbro_process.returncode == 0, f"mbro failed: {stderr}"
        assert "tools" in stdout.lower() or "available" in stdout.lower()

    @pytest.mark.skip(reason="Integration test requires complex async server setup")
    @pytest.mark.asyncio
    async def test_mbro_tool_listing(self, magg_server, magg_server_port):
        """Test that mbro can list tools from Magg."""
        # Test tool listing
        mbro_process = subprocess.Popen(
            ["uv", "run", "python", "-m", "mbro.cli", f"http://localhost:{magg_server_port}", "list"],
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
            text=True
        )

        stdout, stderr = mbro_process.communicate(timeout=10)

        assert mbro_process.returncode == 0
        # Should see Magg's own tools at minimum
        assert "magg" in stdout.lower()


@pytest.mark.integration
class TestMBROIntegration:
    """Integration tests for MBRO with Magg."""

    @pytest.mark.asyncio
    async def test_mbro_search_functionality(self):
        """Test mbro search functionality."""
        # This would test the search capabilities
        # Implementation depends on Magg search being available
        pass

    @pytest.mark.asyncio
    async def test_mbro_tool_execution(self):
        """Test executing tools through mbro."""
        # This would test actual tool execution
        # Implementation depends on having test tools available
        pass
